import styled, { CSSObject } from 'styled-components';

import defaultTheme from '../../theme';
import { flex, paddable } from '../../utils';

export interface FlexColumnProps {
  centered?: boolean;
  verticalAlign?: 'start' | 'center' | 'end';
  padded?: boolean;
  width?: number | number[];
}

export const FlexColumn = styled.div<FlexColumnProps>(
  {
    flexFlow: 'column nowrap',
    height: '100%',
    padding: '0.5em',
  },
  flex(),
  paddable,
  ({ width, padded, theme }) => {
    if (!width) {
      return;
    }

    const { breakpoints } = theme;

    const offset = padded ? '5rem' : '1em';
    const res: CSSObject = {
      flexBasis: '100%',
    };

    if (!Array.isArray(width)) {
      res['@media screen and (min-width: 64em)'] = {
        flexBasis: `${100 * width}%`,
      };

      return res;
    }

    for (let i = 0; i < width.length; i++) {
      if (breakpoints.length < i) {
        break;
      }

      const query = `@media screen and (min-width: ${breakpoints[i]})`;

      res[query] = {
        flexBasis: `calc(${100 * width[i]}% - ${offset})`,
      };
    }

    return res;
  },
);

FlexColumn.defaultProps = {
  theme: defaultTheme,
};

export interface FlexRowProps {
  centered?: boolean;
  verticalAlign?: 'start' | 'center' | 'end';
  padded?: boolean;
}

export const FlexRow = styled.div<FlexRowProps>(
  {
    flexFlow: 'row wrap',
  },
  flex(true),
  paddable,
);

FlexRow.defaultProps = {
  theme: defaultTheme,
};
