import { HiroColors } from './types';
import { CSSObject, DefaultTheme } from 'styled-components';

export const secondary = <
  T extends { color?: HiroColors; secondary?: boolean; theme: DefaultTheme }
>({
  theme,
  secondary,
  color,
}: T) => {
  const colour = theme.colors[color || 'primary'];

  return (
    secondary && {
      border: `1px solid ${colour.default}`,
      backgroundColor: 'transparent',
      color: colour.active,
    }
  );
};

export const text = <T extends { color?: HiroColors; theme: DefaultTheme }>({
  color,
  theme,
}: T): CSSObject | null =>
  color
    ? {
        color: theme.colors[color].default,
      }
    : null;

export const paddable = <T extends { padded?: boolean }>(
  props: T,
): CSSObject | null =>
  props.padded
    ? {
        padding: '1rem 2.5rem',
      }
    : null;

export const flex = (isRow?: boolean) => <
  T extends { verticalAlign?: 'start' | 'center' | 'end'; centered?: boolean }
>({
  verticalAlign,
  centered,
}: T): CSSObject | null => {
  const s: Record<string, string | undefined> = {
    display: 'flex',
    justifyContent: undefined,
    alignItems: undefined,
  };

  if (verticalAlign) {
    s[isRow ? 'alignItems' : 'justifyContent'] = verticalAlign;
  }

  if (centered) {
    s[!isRow ? 'alignItems' : 'justifyContent'] = 'center';
  }

  return s;
};

export const colourable = <
  T extends { color?: HiroColors; theme: DefaultTheme }
>({
  color,
  theme,
}: T): CSSObject =>
  color
    ? {
        backgroundColor: theme.colors[color].default,
        color: 'white',
      }
    : {
        backgroundColor: theme.colors.primary.default,
        color: 'white',
      };

export const clickable = <
  T extends { color?: HiroColors; disabled?: boolean; theme: DefaultTheme }
>({
  color,
  disabled,
  theme,
}: T): CSSObject => {
  return {
    cursor: 'pointer',

    // Disabled
    ...(disabled
      ? {
          pointerEvents: 'none' as const,
          opacity: 0.45,
        }
      : {}),

    // OnClick
    '&:active:hover': {
      backgroundColor: theme.colors[color || 'primary'].active,
    },
    // Hover or focus
    '&:hover, &:focus': {
      backgroundColor: theme.colors[color || 'primary'].hover,
    },
  };
};
