import React from 'react';
import { ThemeProvider } from 'styled-components';

import { storiesOf } from '@storybook/react';
import { action } from '@storybook/addon-actions';
import { linkTo } from '@storybook/addon-links';

import { Welcome } from '@storybook/react/demo';

import {
  Button,
  createTheme,
  Menu,
  MenuItem,
  FlexRow,
  FlexColumn,
  Container,
  Header,
  Text,
  Input,
  GlobalStyle,
} from '../src';

import HiroLogo from './hiro-logo.svg';
import Maintenance from './maintenance.svg';

const theme = createTheme({
  colors: { primary: '#2CB2E8' },
});

console.log('THEME', theme);

storiesOf('Welcome', module).add('to Storybook', () => (
  <Welcome showApp={linkTo('Button')} />
));

storiesOf('Page', module).add('Full', () => (
  <>
    <GlobalStyle />
    <Menu>
      <MenuItem>
        <img src={HiroLogo} width={35} height={35} alt="HIRO Login" />
      </MenuItem>
      <MenuItem>HIRO Status</MenuItem>
    </Menu>
    <Container>
      <FlexRow verticalAlign="center">
        <FlexColumn width={0.4} padded>
          <img src={Maintenance} width="100%" alt="Undergoing Maintenance" />
        </FlexColumn>
        <FlexColumn width={0.6} padded>
          <Header>Undergoing Maintenance</Header>
          <Text>
            We are currently updating the HIRO Platform. This page should
            automatically refresh when the update is complete. You are seeing
            this page because the HIRO Platform is undergoing some essential
            maintenance. We apologise for any inconvenience caused by this
            downtime.
          </Text>
        </FlexColumn>
      </FlexRow>
    </Container>
  </>
));

storiesOf('Inputs', module)
  .add('Button', () => (
    <ThemeProvider theme={theme}>
      <>
        <GlobalStyle />
        <Button onClick={action('clicked')}>Default</Button>
        <Button onClick={action('clicked')} disabled>
          Disabled
        </Button>
        <Button onClick={action('clicked')} secondary>
          Secondary
        </Button>
        <Button onClick={action('clicked')} secondary color="red">
          Secondary
        </Button>
        <Button onClick={action('clicked')} color="red">
          Red
        </Button>
        <Button onClick={action('clicked')} color="green">
          Green
        </Button>
        <Button onClick={action('clicked')} color="blue">
          Blue
        </Button>
        <Button onClick={action('clicked')} color="yellow">
          Yellow
        </Button>
        <Button onClick={action('clicked')} color="purple">
          Purple
        </Button>
      </>
    </ThemeProvider>
  ))
  .add('Input', () => (
    <ThemeProvider theme={theme}>
      <>
        <GlobalStyle />
        <Input placeholder="Placeholder" />
        <br />
        <br />
        <Input defaultValue="Value" />
        <br />
        <br />
        <Input placeholder="Username" label="Username" />
        <Input placeholder="Password" label="Password" />

        <br />
        <br />
        <br />
        <FlexRow>
          <FlexColumn width={0.5}>
            <Input placeholder="Username" label="Username" />
            <Input placeholder="Password" label="Password" />
            <br />

            <Button secondary align="right" color="red">
              Forgot Password
            </Button>
            <Button align="right">Login</Button>
          </FlexColumn>
          <FlexColumn width={0.5}>Test</FlexColumn>
        </FlexRow>
      </>
    </ThemeProvider>
  ));
